"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSyntaxHighlighter = useSyntaxHighlighter;
var _react = require("react");
var _highlighter = require("../syntax/highlighter");
function useSyntaxHighlighter({
  text,
  language,
  languageId,
  theme
}) {
  const [tokens] = (0, _react.useState)([]);
  const [error] = (0, _react.useState)();
  const [isLoading, setIsLoading] = (0, _react.useState)(true);
  (0, _react.useEffect)(() => {
    setIsLoading(true);
    async function highlight() {
      const highlighter = await (0, _highlighter.createHighlighter)({
        langs: [language],
        themes: [theme]
      });
      const result = await highlighter.codeToTokens(text, {
        lang: languageId,
        theme
      });
      result.tokens.forEach((tokens, lineIndex) => {
        tokens.forEach((token, tokenIndex) => {
          console.log('Token detail:', {
            line: lineIndex,
            index: tokenIndex,
            content: token.content,
            color: token.color,
            explanation: token.explanation // Check if explanation gives insight on theme and scope application
          });
        });
      });
    }
    highlight();
  }, [text, language, languageId, theme]);
  return {
    tokens,
    error,
    isLoading
  };
}
//# sourceMappingURL=useSyntaxHighlighter.js.map