"use strict";

import { useEffect, useState } from 'react';
import { createHighlighter } from '../syntax/highlighter';
export function useSyntaxHighlighter({
  text,
  language,
  languageId,
  theme
}) {
  const [tokens] = useState([]);
  const [error] = useState();
  const [isLoading, setIsLoading] = useState(true);
  useEffect(() => {
    setIsLoading(true);
    async function highlight() {
      const highlighter = await createHighlighter({
        langs: [language],
        themes: [theme]
      });
      const result = await highlighter.codeToTokens(text, {
        lang: languageId,
        theme
      });
      result.tokens.forEach((tokens, lineIndex) => {
        tokens.forEach((token, tokenIndex) => {
          console.log('Token detail:', {
            line: lineIndex,
            index: tokenIndex,
            content: token.content,
            color: token.color,
            explanation: token.explanation // Check if explanation gives insight on theme and scope application
          });
        });
      });
    }
    highlight();
  }, [text, language, languageId, theme]);
  return {
    tokens,
    error,
    isLoading
  };
}
//# sourceMappingURL=useSyntaxHighlighter.js.map